@@ -10,7 +10,12 @@ from bleak.backends.device import BLEDevice
 from bleak.backends.scanner import AdvertisementData
 from bleak.backends.service import BleakGATTServiceCollection
 from bleak.exc import BleakDBusError
-from bleak_retry_connector import BleakError, BleakNotFoundError, ble_device_has_changed
+from bleak_retry_connector import (
+    BleakError,
+    BleakNotFoundError,
+    ble_device_has_changed,
+    get_device,
+)
 
 from .const import (
     APPLE_MFR_ID,
@@ -33,7 +38,7 @@ _ADV_LOGGER = logging.getLogger("yalexs_ble_adv")
 
 WrapFuncType = TypeVar("WrapFuncType", bound=Callable[..., Any])
 
-DEFAULT_ATTEMPTS = 3
+DEFAULT_ATTEMPTS = 4
 
 # How long to wait before processing an advertisement change
 ADV_UPDATE_COALESCE_SECONDS = 6.99
@@ -118,29 +123,51 @@ def retry_bluetooth_connection_error(func: WrapFuncType) -> WrapFuncType:
                 # point in retrying.
                 raise
             except RETRY_BACKOFF_EXCEPTIONS as err:
-                if attempt == max_attempts:
+                if attempt >= max_attempts:
+                    _LOGGER.debug(
+                        "%s: %s error calling %s, reach max attempts (%s/%s)",
+                        self.name,
+                        type(err),
+                        func,
+                        attempt,
+                        max_attempts,
+                        exc_info=True,
+                    )
                     if is_disconnected_error(err):
                         raise DisconnectedError(str(err))
                     raise
-                await asyncio.sleep(0.25)
                 _LOGGER.debug(
-                    "%s: %s error calling %s, backing off %ss, retrying...",
+                    "%s: %s error calling %s, backing off %ss, retrying (%s/%s)...",
                     self.name,
                     type(err),
                     func,
                     0.25,
+                    attempt,
+                    max_attempts,
                     exc_info=True,
                 )
+                await asyncio.sleep(0.25)
             except RETRY_EXCEPTIONS as err:
-                if attempt == max_attempts:
+                if attempt >= max_attempts:
+                    _LOGGER.debug(
+                        "%s: %s error calling %s, reach max attempts (%s/%s)",
+                        self.name,
+                        type(err),
+                        func,
+                        attempt,
+                        max_attempts,
+                        exc_info=True,
+                    )
                     if is_disconnected_error(err):
                         raise DisconnectedError(str(err))
                     raise
                 _LOGGER.debug(
-                    "%s: %s error calling %s, retrying...",
+                    "%s: %s error calling %s, retrying  (%s/%s)...",
                     self.name,
                     type(err),
                     func,
+                    attempt,
+                    max_attempts,
                     exc_info=True,
                 )
 
@@ -480,6 +507,9 @@ class PushLock:
             raise RuntimeError("Already running")
         self.last_error = "No Bluetooth advertisement received"
         self._running = True
+        if device := await get_device(self.address):
+            self.set_ble_device(device)
+            self._schedule_update(ADV_UPDATE_COALESCE_SECONDS)
 
         def _cancel() -> None:
             self._running = False
